@@ -18,6 +18,9 @@ mod output;
 mod sheet;
 mod spacing_iterator;
 mod style;
+mod styled_component;
+mod styled_component_impl;
+mod use_style;
 
 #[proc_macro]
 #[proc_macro_error]
@@ -42,3 +45,19 @@ pub fn global_style(input: TokenStream) -> TokenStream {
 pub fn css(input: TokenStream) -> TokenStream {
     css::macro_fn(input.into()).into()
 }
+
+#[proc_macro]
+#[proc_macro_error]
+pub fn use_style(input: TokenStream) -> TokenStream {
+    use_style::macro_fn(input.into()).into()
+}
+
+#[proc_macro_attribute]
+pub fn styled_component(attr: TokenStream, item: TokenStream) -> TokenStream {
+    styled_component::macro_fn(attr, item)
+}
+
+#[proc_macro_attribute]
+pub fn styled_component_impl(attr: TokenStream, item: TokenStream) -> TokenStream {
+    styled_component_impl::macro_fn(attr, item)
+}
